---
title: <span class="badge object-type-scalar"></span> Bars
---
# <span class="badge object-type-scalar"></span> Bars

Pressure: Bars

## Definition

```python
# Pressure: Bars
Bars: typing.Literal["pressurebar"] = "pressurebar"
```
